PooledBytes class final

A leased byte buffer containing a decoded frame.

This is an owned buffer (not tied to the ring buffer), so it's safe to store/mutate as long as you do not call release.

Call release when you are done to return the buffer to the pool.

Properties

buffer Uint8List
The underlying buffer.
no setter
bytesView Uint8List
Convenience view of the first length bytes.
no setter
hashCode int
The hash code for this object.
no setterinherited
length int
Number of valid bytes in buffer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detach() Uint8List
Copies the frame bytes into a fresh tightly-sized Uint8List.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases this buffer back to the pool.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited