A pool of reusable byte buffers.
This is used by pooled framing APIs to reduce per-frame allocations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
Uint8List buffer) → void -
Returns
bufferto the pool for reuse. -
rent(
int minCapacity) → Uint8List -
Returns a buffer with capacity >=
minCapacity. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited