isBorrowed property
Whether the view references internal buffers owned by a driver.
If false, the frame bytes are owned and safe to retain.
Implementation
final bool isBorrowed;
Whether the view references internal buffers owned by a driver.
If false, the frame bytes are owned and safe to retain.
final bool isBorrowed;